<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_acn_startup.case"></a>

# plugins.aea-cli-benchmark.aea`_`cli`_`benchmark.case`_`acn`_`startup.case

Check amount of time for acn connection start.

<a id="plugins.aea-cli-benchmark.aea_cli_benchmark.case_acn_startup.case.run"></a>

#### run

```python
def run(connection: str,
        run_times: int = 10) -> List[Tuple[str, Union[int, float]]]
```

Check construction time and memory usage.

